<?php 
/**
 * Order_info Page Controller
 * @category  Controller
 */
class Order_infoController extends SecureController{
	function __construct(){
		parent::__construct();
		$this->tablename = "order_info";
	}
	/**
     * List page records
     * @param $fieldname (filter record by a field) 
     * @param $fieldvalue (filter field value)
     * @return BaseView
     */
	function index($fieldname = null , $fieldvalue = null){
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$fields = array("id", 
			"order_md5", 
			"order_status", 
			"restaurant_id", 
			"restaurnat_name", 
			"restaurant_address", 
			"restaurant_email", 
			"restaurant_cc_email", 
			"restaurant_whatsapp", 
			"supplier_id", 
			"supplier_name", 
			"supplier_address", 
			"supplier_email", 
			"supplier_cc_email", 
			"supplier_whatsapp", 
			"delivery_date", 
			"delivery_note", 
			"record_date");
		$pagination = $this->get_pagination(MAX_RECORD_COUNT); // get current pagination e.g array(page_number, page_limit)
		//search table record
		if(!empty($request->search)){
			$text = trim($request->search); 
			$search_condition = "(
				order_info.id LIKE ? OR 
				order_info.order_md5 LIKE ? OR 
				order_info.order_status LIKE ? OR 
				order_info.restaurant_id LIKE ? OR 
				order_info.restaurnat_name LIKE ? OR 
				order_info.restaurant_address LIKE ? OR 
				order_info.restaurant_email LIKE ? OR 
				order_info.restaurant_cc_email LIKE ? OR 
				order_info.restaurant_whatsapp LIKE ? OR 
				order_info.supplier_id LIKE ? OR 
				order_info.supplier_name LIKE ? OR 
				order_info.supplier_address LIKE ? OR 
				order_info.supplier_email LIKE ? OR 
				order_info.supplier_cc_email LIKE ? OR 
				order_info.supplier_whatsapp LIKE ? OR 
				order_info.delivery_date LIKE ? OR 
				order_info.delivery_note LIKE ? OR 
				order_info.record_date LIKE ?
			)";
			$search_params = array(
				"%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%"
			);
			//setting search conditions
			$db->where($search_condition, $search_params);
			 //template to use when ajax search
			$this->view->search_template = "order_info/search.php";
		}
		if(!empty($request->orderby)){
			$orderby = $request->orderby;
			$ordertype = (!empty($request->ordertype) ? $request->ordertype : ORDER_TYPE);
			$db->orderBy($orderby, $ordertype);
		}
		else{
			$db->orderBy("order_info.id", ORDER_TYPE);
		}
		if($fieldname){
			$db->where($fieldname , $fieldvalue); //filter by a single field name
		}
		$tc = $db->withTotalCount();
		$records = $db->get($tablename, $pagination, $fields);
		$records_count = count($records);
		$total_records = intval($tc->totalCount);
		$page_limit = $pagination[1];
		$total_pages = ceil($total_records / $page_limit);
		$data = new stdClass;
		$data->records = $records;
		$data->record_count = $records_count;
		$data->total_records = $total_records;
		$data->total_page = $total_pages;
		if($db->getLastError()){
			$this->set_page_error();
		}
		$page_title = $this->view->page_title = "Order Info";
		$this->view->report_filename = date('Y-m-d') . '-' . $page_title;
		$this->view->report_title = $page_title;
		$this->view->report_layout = "report_layout.php";
		$this->view->report_paper_size = "A4";
		$this->view->report_orientation = "portrait";
		$this->render_view("order_info/list.php", $data); //render the full page
	}
	/**
     * View record detail 
	 * @param $rec_id (select record by table primary key) 
     * @param $value value (select record by value of field name(rec_id))
     * @return BaseView
     */
	function view($rec_id = null, $value = null){
		$request = $this->request;
		$db = $this->GetModel();
		$rec_id = $this->rec_id = urldecode($rec_id);
		$tablename = $this->tablename;
		$fields = array("id", 
			"order_md5", 
			"restaurant_id", 
			"restaurnat_name", 
			"restaurant_address", 
			"restaurant_email", 
			"restaurant_cc_email", 
			"restaurant_whatsapp", 
			"supplier_id", 
			"supplier_name", 
			"supplier_address", 
			"supplier_email", 
			"supplier_cc_email", 
			"supplier_whatsapp", 
			"delivery_date", 
			"delivery_note", 
			"order_status", 
			"record_date");
		if($value){
			$db->where($rec_id, urldecode($value)); //select record based on field name
		}
		else{
			$db->where("order_info.id", $rec_id);; //select record based on primary key
		}
		$record = $db->getOne($tablename, $fields );
		if($record){
			$page_title = $this->view->page_title = "View  Order Info";
		$this->view->report_filename = date('Y-m-d') . '-' . $page_title;
		$this->view->report_title = $page_title;
		$this->view->report_layout = "report_layout.php";
		$this->view->report_paper_size = "A4";
		$this->view->report_orientation = "portrait";
		}
		else{
			if($db->getLastError()){
				$this->set_page_error();
			}
			else{
				$this->set_page_error("No record found");
			}
		}
		return $this->render_view("order_info/view.php", $record);
	}
	/**
     * Insert new record to the database table
	 * @param $formdata array() from $_POST
     * @return BaseView
     */
	function add($formdata = null){
		if($formdata){
			$db = $this->GetModel();
			$tablename = $this->tablename;
			$request = $this->request;
			//fillable fields
			$fields = $this->fields = array("order_md5","restaurant_id","restaurnat_name","restaurant_address","restaurant_email","restaurant_cc_email","restaurant_whatsapp","supplier_id","supplier_name","supplier_address","supplier_email","supplier_cc_email","supplier_whatsapp","delivery_date","delivery_note","order_status","record_date");
			$postdata = $this->format_request_data($formdata);
			$this->rules_array = array(
				'restaurant_email' => 'required|valid_email',
				'restaurant_cc_email' => 'valid_email',
				'supplier_name' => 'required',
				'supplier_email' => 'valid_email',
				'supplier_cc_email' => 'valid_email',
				'delivery_date' => 'required',
				'order_status' => 'required',
			);
			$this->sanitize_array = array(
				'restaurant_email' => 'sanitize_string',
				'restaurant_cc_email' => 'sanitize_string',
				'restaurant_whatsapp' => 'sanitize_string',
				'supplier_name' => 'sanitize_string',
				'supplier_email' => 'sanitize_string',
				'supplier_cc_email' => 'sanitize_string',
				'supplier_whatsapp' => 'sanitize_string',
				'delivery_date' => 'sanitize_string',
				'delivery_note' => 'sanitize_string',
				'order_status' => 'sanitize_string',
			);
			$this->filter_vals = true; //set whether to remove empty fields
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			$modeldata['record_date'] = datetime_now();
			if($this->validated()){
				$rec_id = $this->rec_id = $db->insert($tablename, $modeldata);
				if($rec_id){
					$this->set_flash_msg("Record added successfully", "success");
					return	$this->redirect("order_info");
				}
				else{
					$this->set_page_error();
				}
			}
		}
		$page_title = $this->view->page_title = "Add New Order Info";
		$this->render_view("order_info/add.php");
	}
	/**
     * Update table record with formdata
	 * @param $rec_id (select record by table primary key)
	 * @param $formdata array() from $_POST
     * @return array
     */
	function edit($rec_id = null, $formdata = null){
		$request = $this->request;
		$db = $this->GetModel();
		$this->rec_id = $rec_id;
		$tablename = $this->tablename;
		 //editable fields
		$fields = $this->fields = array("id","order_md5","restaurant_id","restaurnat_name","restaurant_address","restaurant_email","restaurant_cc_email","restaurant_whatsapp","supplier_id","supplier_name","supplier_address","supplier_email","supplier_cc_email","supplier_whatsapp","delivery_date","delivery_note","order_status","record_date");
		if($formdata){
			$postdata = $this->format_request_data($formdata);
			$this->rules_array = array(
				'restaurant_email' => 'required|valid_email',
				'restaurant_cc_email' => 'valid_email',
				'supplier_name' => 'required',
				'supplier_email' => 'valid_email',
				'supplier_cc_email' => 'valid_email',
				'delivery_date' => 'required',
				'order_status' => 'required',
			);
			$this->sanitize_array = array(
				'restaurant_email' => 'sanitize_string',
				'restaurant_cc_email' => 'sanitize_string',
				'restaurant_whatsapp' => 'sanitize_string',
				'supplier_name' => 'sanitize_string',
				'supplier_email' => 'sanitize_string',
				'supplier_cc_email' => 'sanitize_string',
				'supplier_whatsapp' => 'sanitize_string',
				'delivery_date' => 'sanitize_string',
				'delivery_note' => 'sanitize_string',
				'order_status' => 'sanitize_string',
			);
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			$modeldata['record_date'] = datetime_now();
			if($this->validated()){
				$db->where("order_info.id", $rec_id);;
				$bool = $db->update($tablename, $modeldata);
				$numRows = $db->getRowCount(); //number of affected rows. 0 = no record field updated
				if($bool && $numRows){
		# Statement to execute after adding record
			$db->where("id", $rec_id);
$order_md5 = $db->getValue("order_info", "order_md5");
$db->where("id", $rec_id);
$order_status = $db->getValue("order_info", "order_status");
$db->where("id", $rec_id);
$restaurant_email = $db->getValue("order_info", "restaurant_email");
$db->where("id", $rec_id);
$restaurant_cc_email = $db->getValue("order_info", "restaurant_cc_email");
$db->where("id", $rec_id);
$supplier_email = $db->getValue("order_info", "supplier_email");
$db->where("id", $rec_id);
$supplier_cc_email = $db->getValue("order_info", "supplier_cc_email");
if($order_status=="Complete")
{
$url = "email/index.php?omd=$order_md5";   
redirect_to_page($url);
exit;
//$mailtitle      = "New Order/Neue Bestellung";
//$mailbody       =  $url;
//$receiver_email = DEFAULT_EMAIL;
//$mailer         = new Mailer;
//if(isset($restaurant_email))
//{
//$mailer->send_mail($restaurant_email, $mailtitle, $mailbody);
//}
//if(isset($restaurant_cc_email))
//{
    //$mailer->send_mail($restaurant_cc_email, $mailtitle, $mailbody);
//}
//if(isset($supplier_email))
//{
    //$mailer->send_mail($supplier_email, $mailtitle, $mailbody);
//}
//if(isset($supplier_cc_email))
    //$mailer->send_mail($supplier_cc_email, $mailtitle, $mailbody);
//}
}
		# End of after update statement
					$this->set_flash_msg("Record updated successfully", "success");
					return $this->redirect("order_info/order_list");
				}
				else{
					if($db->getLastError()){
						$this->set_page_error();
					}
					elseif(!$numRows){
						//not an error, but no record was updated
						$page_error = "No record updated";
						$this->set_page_error($page_error);
						$this->set_flash_msg($page_error, "warning");
						return	$this->redirect("order_info/order_list");
					}
				}
			}
		}
		$db->where("order_info.id", $rec_id);;
		$data = $db->getOne($tablename, $fields);
		$page_title = $this->view->page_title = "Edit  Order Info";
		if(!$data){
			$this->set_page_error();
		}
		return $this->render_view("order_info/edit.php", $data);
	}
	/**
     * Update single field
	 * @param $rec_id (select record by table primary key)
	 * @param $formdata array() from $_POST
     * @return array
     */
	function editfield($rec_id = null, $formdata = null){
		$db = $this->GetModel();
		$this->rec_id = $rec_id;
		$tablename = $this->tablename;
		//editable fields
		$fields = $this->fields = array("id","order_md5","restaurant_id","restaurnat_name","restaurant_address","restaurant_email","restaurant_cc_email","restaurant_whatsapp","supplier_id","supplier_name","supplier_address","supplier_email","supplier_cc_email","supplier_whatsapp","delivery_date","delivery_note","order_status","record_date");
		$page_error = null;
		if($formdata){
			$postdata = array();
			$fieldname = $formdata['name'];
			$fieldvalue = $formdata['value'];
			$postdata[$fieldname] = $fieldvalue;
			$postdata = $this->format_request_data($postdata);
			$this->rules_array = array(
				'restaurant_email' => 'required|valid_email',
				'restaurant_cc_email' => 'valid_email',
				'supplier_name' => 'required',
				'supplier_email' => 'valid_email',
				'supplier_cc_email' => 'valid_email',
				'delivery_date' => 'required',
				'order_status' => 'required',
			);
			$this->sanitize_array = array(
				'restaurant_email' => 'sanitize_string',
				'restaurant_cc_email' => 'sanitize_string',
				'restaurant_whatsapp' => 'sanitize_string',
				'supplier_name' => 'sanitize_string',
				'supplier_email' => 'sanitize_string',
				'supplier_cc_email' => 'sanitize_string',
				'supplier_whatsapp' => 'sanitize_string',
				'delivery_date' => 'sanitize_string',
				'delivery_note' => 'sanitize_string',
				'order_status' => 'sanitize_string',
			);
			$this->filter_rules = true; //filter validation rules by excluding fields not in the formdata
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			if($this->validated()){
				$db->where("order_info.id", $rec_id);;
				$bool = $db->update($tablename, $modeldata);
				$numRows = $db->getRowCount();
				if($bool && $numRows){
					return render_json(
						array(
							'num_rows' =>$numRows,
							'rec_id' =>$rec_id,
						)
					);
				}
				else{
					if($db->getLastError()){
						$page_error = $db->getLastError();
					}
					elseif(!$numRows){
						$page_error = "No record updated";
					}
					render_error($page_error);
				}
			}
			else{
				render_error($this->view->page_error);
			}
		}
		return null;
	}
	/**
     * Delete record from the database
	 * Support multi delete by separating record id by comma.
     * @return BaseView
     */
	function delete($rec_id = null){
		Csrf::cross_check();
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$this->rec_id = $rec_id;
		//form multiple delete, split record id separated by comma into array
		$arr_rec_id = array_map('trim', explode(",", $rec_id));
		$db->where("order_info.id", $arr_rec_id, "in");
		$bool = $db->delete($tablename);
		if($bool){
		#Statement to execute after delete record
$db->where("order_id", $rec_id);
$bool = $db->delete("order_item");
		# End of after delete statement
			$this->set_flash_msg("Record deleted successfully", "success");
		}
		elseif($db->getLastError()){
			$page_error = $db->getLastError();
			$this->set_flash_msg($page_error, "danger");
		}
		return	$this->redirect("order_info");
	}
	/**
     * List page records
     * @param $fieldname (filter record by a field) 
     * @param $fieldvalue (filter field value)
     * @return BaseView
     */
	function order_list($fieldname = null , $fieldvalue = null){
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$fields = array("id", 
			"order_status", 
			"order_md5", 
			"restaurant_id", 
			"restaurnat_name", 
			"restaurant_address", 
			"restaurant_email", 
			"restaurant_cc_email", 
			"restaurant_whatsapp", 
			"supplier_id", 
			"supplier_name", 
			"supplier_address", 
			"supplier_email", 
			"supplier_cc_email", 
			"supplier_whatsapp", 
			"delivery_date", 
			"delivery_note", 
			"record_date");
		$pagination = $this->get_pagination(MAX_RECORD_COUNT); // get current pagination e.g array(page_number, page_limit)
	#Statement to execute before list record
if(isset($_GET['rid']) && isset($_GET['sid']))
{
$rid = $_GET['rid'];
$db->where("restaurant_id", $rid);
$restaurnat_name = $db->getValue("restaurant", "name");
$db->where("restaurant_id", $rid);
$restaurant_address = $db->getValue("restaurant", "address");
$db->where("restaurant_id", $rid);
$restaurant_email = $db->getValue("restaurant", "email");
$db->where("restaurant_id", $rid);
$restaurant_cc_email = $db->getValue("restaurant", "cc_email");
$db->where("restaurant_id", $rid);
$restaurant_whatsapp = $db->getValue("restaurant", "whatsapp");
$sid = $_GET['sid'];
$db->where("supplier_id", $sid);
$supplier_name = $db->getValue("supplier", "name");
$db->where("supplier_id", $sid);
$supplier_address = $db->getValue("supplier", "address");
$db->where("supplier_id", $sid);
$supplier_email = $db->getValue("supplier", "email");
$db->where("supplier_id", $sid);
$supplier_cc_email = $db->getValue("supplier", "cc_email");
$db->where("supplier_id", $sid);
$supplier_whatsapp = $db->getValue("supplier", "whatsapp");
$record_date = date("Y-m-d H:i:s");
$order_status = "New";
$con = mysqli_connect(DB_HOST, DB_USERNAME, DB_PASSWORD, DB_NAME);
if( mysqli_connect_error()) echo "Failed to connect to MySQL: " . mysqli_connect_error();  
$con->set_charset("utf8mb4");
$insert = "INSERT INTO order_info(supplier_id,restaurant_id,restaurnat_name,restaurant_address,restaurant_email,restaurant_cc_email,restaurant_whatsapp,supplier_name,supplier_address,supplier_email,supplier_cc_email,supplier_whatsapp,record_date,order_status)VALUES('$sid','$rid','$restaurnat_name','$restaurant_address','$restaurant_email','$restaurant_cc_email','$restaurant_whatsapp','$supplier_name','$supplier_address','$supplier_email','$supplier_cc_email','$supplier_whatsapp','$record_date','$order_status')";
mysqli_query($con,$insert);
$order_id = mysqli_insert_id($con);
$order_md5 = md5($order_id);
$sql_update = "UPDATE order_info SET order_md5 ='$order_md5' WHERE id='$order_id'";
mysqli_query($con,$sql_update);
$sql    = "SELECT * FROM product WHERE supplier_id='$sid'";
$result = mysqli_query($con,$sql);
while($row_product = mysqli_fetch_assoc($result))
{
    $article_name          = $row_product['name'];
    $article_nr            = $row_product['article_nr'];
    $article_description   = null;
    $article_category_id   = $row_product['category_id'];
    $article_category_name = $row_product['category_name'];
    $supplier_id   = $row_product['supplier_id'];
    $supplier_name = $row_product['supplier_name'];
    $sql_insert = "INSERT INTO order_item(order_id,order_md5,article_name,article_nr,article_description,article_category_id,article_category_name,supplier_id,supplier_name)VALUES('$order_id','$order_md5','$article_name','$article_nr','$article_description','$article_category_id','$article_category_name','$supplier_id','$supplier_name')";
    mysqli_query($con,$sql_insert);
}
redirect_to_page("order_info/order_list");
}
	# End of before list statement
		//search table record
		if(!empty($request->search)){
			$text = trim($request->search); 
			$search_condition = "(
				order_info.id LIKE ? OR 
				order_info.order_status LIKE ? OR 
				order_info.order_md5 LIKE ? OR 
				order_info.restaurant_id LIKE ? OR 
				order_info.restaurnat_name LIKE ? OR 
				order_info.restaurant_address LIKE ? OR 
				order_info.restaurant_email LIKE ? OR 
				order_info.restaurant_cc_email LIKE ? OR 
				order_info.restaurant_whatsapp LIKE ? OR 
				order_info.supplier_id LIKE ? OR 
				order_info.supplier_name LIKE ? OR 
				order_info.supplier_address LIKE ? OR 
				order_info.supplier_email LIKE ? OR 
				order_info.supplier_cc_email LIKE ? OR 
				order_info.supplier_whatsapp LIKE ? OR 
				order_info.delivery_date LIKE ? OR 
				order_info.delivery_note LIKE ? OR 
				order_info.record_date LIKE ?
			)";
			$search_params = array(
				"%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%"
			);
			//setting search conditions
			$db->where($search_condition, $search_params);
			 //template to use when ajax search
			$this->view->search_template = "order_info/search.php";
		}
		if(!empty($request->orderby)){
			$orderby = $request->orderby;
			$ordertype = (!empty($request->ordertype) ? $request->ordertype : ORDER_TYPE);
			$db->orderBy($orderby, $ordertype);
		}
		else{
			$db->orderBy("order_info.id", ORDER_TYPE);
		}
		$db->where("restaurant_id='". USER_ID . "'");
		if($fieldname){
			$db->where($fieldname , $fieldvalue); //filter by a single field name
		}
		$tc = $db->withTotalCount();
		$records = $db->get($tablename, $pagination, $fields);
		$records_count = count($records);
		$total_records = intval($tc->totalCount);
		$page_limit = $pagination[1];
		$total_pages = ceil($total_records / $page_limit);
		$data = new stdClass;
		$data->records = $records;
		$data->record_count = $records_count;
		$data->total_records = $total_records;
		$data->total_page = $total_pages;
		if($db->getLastError()){
			$this->set_page_error();
		}
		$page_title = $this->view->page_title = "Order Info";
		$this->render_view("order_info/order_list.php", $data); //render the full page
	}
}
