<?php 
/**
 * Order_item Page Controller
 * @category  Controller
 */
class Order_itemController extends SecureController{
	function __construct(){
		parent::__construct();
		$this->tablename = "order_item";
	}
	/**
     * List page records
     * @param $fieldname (filter record by a field) 
     * @param $fieldvalue (filter field value)
     * @return BaseView
     */
	function index($fieldname = null , $fieldvalue = null){
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$fields = array("id", 
			"order_id", 
			"order_md5", 
			"article_name", 
			"article_nr", 
			"quantity", 
			"article_description", 
			"article_category_name", 
			"article_category_id", 
			"supplier_id", 
			"supplier_name");
		$pagination = $this->get_pagination(500); // get current pagination e.g array(page_number, page_limit)
		//search table record
		if(!empty($request->search)){
			$text = trim($request->search); 
			$search_condition = "(
				order_item.id LIKE ? OR 
				order_item.order_id LIKE ? OR 
				order_item.order_md5 LIKE ? OR 
				order_item.article_name LIKE ? OR 
				order_item.article_nr LIKE ? OR 
				order_item.quantity LIKE ? OR 
				order_item.article_description LIKE ? OR 
				order_item.article_category_name LIKE ? OR 
				order_item.article_category_id LIKE ? OR 
				order_item.supplier_id LIKE ? OR 
				order_item.supplier_name LIKE ?
			)";
			$search_params = array(
				"%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%"
			);
			//setting search conditions
			$db->where($search_condition, $search_params);
			 //template to use when ajax search
			$this->view->search_template = "order_item/search.php";
		}
		if(!empty($request->orderby)){
			$orderby = $request->orderby;
			$ordertype = (!empty($request->ordertype) ? $request->ordertype : ORDER_TYPE);
			$db->orderBy($orderby, $ordertype);
		}
		else{
			$db->orderBy("order_item.id", ORDER_TYPE);
		}
		$db->where("order_md5='". $_GET['omd'] . "'");
		if($fieldname){
			$db->where($fieldname , $fieldvalue); //filter by a single field name
		}
		if(!empty($request->order_item_article_category_id)){
			$val = $request->order_item_article_category_id;
			$db->where("order_item.article_category_id", $val , "=");
		}
		$tc = $db->withTotalCount();
		$records = $db->get($tablename, $pagination, $fields);
		$records_count = count($records);
		$total_records = intval($tc->totalCount);
		$page_limit = $pagination[1];
		$total_pages = ceil($total_records / $page_limit);
		$data = new stdClass;
		$data->records = $records;
		$data->record_count = $records_count;
		$data->total_records = $total_records;
		$data->total_page = $total_pages;
		if($db->getLastError()){
			$this->set_page_error();
		}
		$page_title = $this->view->page_title = "Order Item";
		$this->render_view("order_item/list.php", $data); //render the full page
	}
	/**
     * View record detail 
	 * @param $rec_id (select record by table primary key) 
     * @param $value value (select record by value of field name(rec_id))
     * @return BaseView
     */
	function view($rec_id = null, $value = null){
		$request = $this->request;
		$db = $this->GetModel();
		$rec_id = $this->rec_id = urldecode($rec_id);
		$tablename = $this->tablename;
		$fields = array("id", 
			"order_id", 
			"order_md5", 
			"article_name", 
			"article_nr", 
			"article_description", 
			"article_category_id", 
			"quantity", 
			"article_category_name", 
			"supplier_id", 
			"supplier_name");
		if($value){
			$db->where($rec_id, urldecode($value)); //select record based on field name
		}
		else{
			$db->where("order_item.id", $rec_id);; //select record based on primary key
		}
		$record = $db->getOne($tablename, $fields );
		if($record){
			$page_title = $this->view->page_title = "View  Order Item";
		$this->view->report_filename = date('Y-m-d') . '-' . $page_title;
		$this->view->report_title = $page_title;
		$this->view->report_layout = "report_layout.php";
		$this->view->report_paper_size = "A4";
		$this->view->report_orientation = "portrait";
		}
		else{
			if($db->getLastError()){
				$this->set_page_error();
			}
			else{
				$this->set_page_error("No record found");
			}
		}
		return $this->render_view("order_item/view.php", $record);
	}
	/**
     * Insert new record to the database table
	 * @param $formdata array() from $_POST
     * @return BaseView
     */
	function add($formdata = null){
		if($formdata){
			$db = $this->GetModel();
			$tablename = $this->tablename;
			$request = $this->request;
			//fillable fields
			$fields = $this->fields = array("order_id","order_md5","supplier_id","supplier_name","article_name","article_nr","article_category_id","quantity","article_description");
			$postdata = $this->format_request_data($formdata);
			$this->rules_array = array(
				'order_id' => 'required',
				'order_md5' => 'required',
				'supplier_id' => 'required',
				'supplier_name' => 'required',
				'article_name' => 'required',
				'article_category_id' => 'required',
				'quantity' => 'required',
			);
			$this->sanitize_array = array(
				'order_id' => 'sanitize_string',
				'order_md5' => 'sanitize_string',
				'supplier_id' => 'sanitize_string',
				'supplier_name' => 'sanitize_string',
				'article_name' => 'sanitize_string',
				'article_nr' => 'sanitize_string',
				'article_category_id' => 'sanitize_string',
				'quantity' => 'sanitize_string',
				'article_description' => 'sanitize_string',
			);
			$this->filter_vals = true; //set whether to remove empty fields
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			if($this->validated()){
				$rec_id = $this->rec_id = $db->insert($tablename, $modeldata);
				if($rec_id){
		# Statement to execute after adding record
		$db->where("id", $rec_id);
$category_id = $db->getValue("order_item", "article_category_id");
$db->where("id", $category_id);
$category_name = $db->getValue("category", "name");
$table_data = array(
    "article_category_name" => $category_name
);
$db->where("id", $rec_id);
$bool = $db->update("order_item", $table_data);
$db->where("id", $rec_id);
$order_md5 = $db->getValue("order_item", "order_md5");
$db->where("id", $rec_id);
$order_id = $db->getValue("order_item", "order_id");
//add in product table//
$db->where("id", $rec_id);
$name = $db->getValue("order_item", "article_name");
$db->where("id", $rec_id);
$article_nr = $db->getValue("order_item", "article_nr");
$db->where("id", $rec_id);
$article_nr = $db->getValue("order_item", "article_nr");
$db->where("id", $rec_id);
$supplier_id = $db->getValue("order_item", "supplier_id");
$db->where("id", $rec_id);
$supplier_name = $db->getValue("order_item", "supplier_name");
$status = "Online";
$table_data = array(
    "name" =>$name,
    "article_nr" => $article_nr,
    "category_id" => $category_id,
    "category_name" => $category_name,
    "status" => $status,
    "supplier_id" =>$supplier_id,
    "supplier_name" =>$supplier_name
);
$db->insert("product", $table_data);
redirect_to_page("order_item?omd=$order_md5&oid=$order_id&supplier_id=$supplier_id&supplier_name=$supplier_name");
exit;
		# End of after add statement
					$this->set_flash_msg("Record added successfully", "success");
					return	$this->redirect("order_item");
				}
				else{
					$this->set_page_error();
				}
			}
		}
		$page_title = $this->view->page_title = "Add New Order Item";
		$this->render_view("order_item/add.php");
	}
	/**
     * Update table record with formdata
	 * @param $rec_id (select record by table primary key)
	 * @param $formdata array() from $_POST
     * @return array
     */
	function edit($rec_id = null, $formdata = null){
		$request = $this->request;
		$db = $this->GetModel();
		$this->rec_id = $rec_id;
		$tablename = $this->tablename;
		 //editable fields
		$fields = $this->fields = array("id","order_id","order_md5","supplier_id","supplier_name","article_name","article_nr","article_category_id","quantity","article_description");
		if($formdata){
			$postdata = $this->format_request_data($formdata);
			$this->rules_array = array(
				'order_id' => 'required',
				'order_md5' => 'required',
				'supplier_id' => 'required',
				'supplier_name' => 'required',
				'article_name' => 'required',
				'article_category_id' => 'required',
				'quantity' => 'required',
			);
			$this->sanitize_array = array(
				'order_id' => 'sanitize_string',
				'order_md5' => 'sanitize_string',
				'supplier_id' => 'sanitize_string',
				'supplier_name' => 'sanitize_string',
				'article_name' => 'sanitize_string',
				'article_nr' => 'sanitize_string',
				'article_category_id' => 'sanitize_string',
				'quantity' => 'sanitize_string',
				'article_description' => 'sanitize_string',
			);
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			if($this->validated()){
				$db->where("order_item.id", $rec_id);;
				$bool = $db->update($tablename, $modeldata);
				$numRows = $db->getRowCount(); //number of affected rows. 0 = no record field updated
				if($bool && $numRows){
		# Statement to execute after adding record
			$db->where("id", $rec_id);
$category_id = $db->getValue("order_item", "article_category_id");
$db->where("id", $category_id);
$category_name = $db->getValue("category", "name");
$table_data = array(
    "article_category_name" => $category_name
);
$db->where("id", $rec_id);
$bool = $db->update("order_item", $table_data);
$db->where("id", $rec_id);
$order_md5 = $db->getValue("order_item", "order_md5");
$db->where("id", $rec_id);
$order_id = $db->getValue("order_item", "order_id");
$db->where("id", $rec_id);
$supplier_id = $db->getValue("order_item", "supplier_id");
$db->where("id", $rec_id);
$supplier_name = $db->getValue("order_item", "supplier_name");
redirect_to_page("order_item?omd=$order_md5&oid=$order_id&supplier_id=&supplier_name");
exit;
		# End of after update statement
					$this->set_flash_msg("Record updated successfully", "success");
					return $this->redirect("order_item");
				}
				else{
					if($db->getLastError()){
						$this->set_page_error();
					}
					elseif(!$numRows){
						//not an error, but no record was updated
						$page_error = "No record updated";
						$this->set_page_error($page_error);
						$this->set_flash_msg($page_error, "warning");
						return	$this->redirect("order_item");
					}
				}
			}
		}
		$db->where("order_item.id", $rec_id);;
		$data = $db->getOne($tablename, $fields);
		$page_title = $this->view->page_title = "Edit  Order Item";
		if(!$data){
			$this->set_page_error();
		}
		return $this->render_view("order_item/edit.php", $data);
	}
	/**
     * Update single field
	 * @param $rec_id (select record by table primary key)
	 * @param $formdata array() from $_POST
     * @return array
     */
	function editfield($rec_id = null, $formdata = null){
		$db = $this->GetModel();
		$this->rec_id = $rec_id;
		$tablename = $this->tablename;
		//editable fields
		$fields = $this->fields = array("id","order_id","order_md5","supplier_id","supplier_name","article_name","article_nr","article_category_id","quantity","article_description");
		$page_error = null;
		if($formdata){
			$postdata = array();
			$fieldname = $formdata['name'];
			$fieldvalue = $formdata['value'];
			$postdata[$fieldname] = $fieldvalue;
			$postdata = $this->format_request_data($postdata);
			$this->rules_array = array(
				'order_id' => 'required',
				'order_md5' => 'required',
				'supplier_id' => 'required',
				'supplier_name' => 'required',
				'article_name' => 'required',
				'article_category_id' => 'required',
				'quantity' => 'required',
			);
			$this->sanitize_array = array(
				'order_id' => 'sanitize_string',
				'order_md5' => 'sanitize_string',
				'supplier_id' => 'sanitize_string',
				'supplier_name' => 'sanitize_string',
				'article_name' => 'sanitize_string',
				'article_nr' => 'sanitize_string',
				'article_category_id' => 'sanitize_string',
				'quantity' => 'sanitize_string',
				'article_description' => 'sanitize_string',
			);
			$this->filter_rules = true; //filter validation rules by excluding fields not in the formdata
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			if($this->validated()){
				$db->where("order_item.id", $rec_id);;
				$bool = $db->update($tablename, $modeldata);
				$numRows = $db->getRowCount();
				if($bool && $numRows){
					return render_json(
						array(
							'num_rows' =>$numRows,
							'rec_id' =>$rec_id,
						)
					);
				}
				else{
					if($db->getLastError()){
						$page_error = $db->getLastError();
					}
					elseif(!$numRows){
						$page_error = "No record updated";
					}
					render_error($page_error);
				}
			}
			else{
				render_error($this->view->page_error);
			}
		}
		return null;
	}
	/**
     * Delete record from the database
	 * Support multi delete by separating record id by comma.
     * @return BaseView
     */
	function delete($rec_id = null){
		Csrf::cross_check();
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$this->rec_id = $rec_id;
		//form multiple delete, split record id separated by comma into array
		$arr_rec_id = array_map('trim', explode(",", $rec_id));
	#Statement to execute before delete record
	$db->where("id", $rec_id);
$order_md5 = $db->getValue("order_item", "order_md5");
$db->where("id", $rec_id);
$order_id = $db->getValue("order_item", "order_id");
	# End of before delete statement
		$db->where("order_item.id", $arr_rec_id, "in");
		$bool = $db->delete($tablename);
		if($bool){
		#Statement to execute after delete record
		redirect_to_page("order_item?omd=$order_md5&oid=$order_id");
exit;
		# End of after delete statement
			$this->set_flash_msg("Record deleted successfully", "success");
		}
		elseif($db->getLastError()){
			$page_error = $db->getLastError();
			$this->set_flash_msg($page_error, "danger");
		}
		return	$this->redirect("order_item");
	}
}
