<?php 
/**
 * Supplier Page Controller
 * @category  Controller
 */
class SupplierController extends SecureController{
	function __construct(){
		parent::__construct();
		$this->tablename = "supplier";
	}
	/**
     * List page records
     * @param $fieldname (filter record by a field) 
     * @param $fieldvalue (filter field value)
     * @return BaseView
     */
	function index($fieldname = null , $fieldvalue = null){
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$fields = array("supplier.id", 
			"supplier.name", 
			"supplier.address", 
			"supplier.phone", 
			"supplier.type", 
			"supplier.email", 
			"supplier.cc_email", 
			"supplier.whatsapp", 
			"supplier.logo", 
			"supplier.restaurant_id", 
			"user.name AS user_name", 
			"supplier.supplier_id");
		$pagination = $this->get_pagination(MAX_RECORD_COUNT); // get current pagination e.g array(page_number, page_limit)
		//search table record
		if(!empty($request->search)){
			$text = trim($request->search); 
			$search_condition = "(
				supplier.id LIKE ? OR 
				supplier.name LIKE ? OR 
				supplier.address LIKE ? OR 
				supplier.phone LIKE ? OR 
				supplier.type LIKE ? OR 
				supplier.email LIKE ? OR 
				supplier.cc_email LIKE ? OR 
				supplier.whatsapp LIKE ? OR 
				supplier.logo LIKE ? OR 
				supplier.restaurant_id LIKE ? OR 
				supplier.supplier_id LIKE ?
			)";
			$search_params = array(
				"%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%"
			);
			//setting search conditions
			$db->where($search_condition, $search_params);
			 //template to use when ajax search
			$this->view->search_template = "supplier/search.php";
		}
		$db->join("user", "supplier.restaurant_id = user.id", "INNER");
		if(!empty($request->orderby)){
			$orderby = $request->orderby;
			$ordertype = (!empty($request->ordertype) ? $request->ordertype : ORDER_TYPE);
			$db->orderBy($orderby, $ordertype);
		}
		else{
			$db->orderBy("supplier.id", ORDER_TYPE);
		}
		if($fieldname){
			$db->where($fieldname , $fieldvalue); //filter by a single field name
		}
		$tc = $db->withTotalCount();
		$records = $db->get($tablename, $pagination, $fields);
		$records_count = count($records);
		$total_records = intval($tc->totalCount);
		$page_limit = $pagination[1];
		$total_pages = ceil($total_records / $page_limit);
		$data = new stdClass;
		$data->records = $records;
		$data->record_count = $records_count;
		$data->total_records = $total_records;
		$data->total_page = $total_pages;
		if($db->getLastError()){
			$this->set_page_error();
		}
		$page_title = $this->view->page_title = "Supplier";
		$this->view->report_filename = date('Y-m-d') . '-' . $page_title;
		$this->view->report_title = $page_title;
		$this->view->report_layout = "report_layout.php";
		$this->view->report_paper_size = "A4";
		$this->view->report_orientation = "portrait";
		$this->render_view("supplier/list.php", $data); //render the full page
	}
	/**
     * View record detail 
	 * @param $rec_id (select record by table primary key) 
     * @param $value value (select record by value of field name(rec_id))
     * @return BaseView
     */
	function view($rec_id = null, $value = null){
		$request = $this->request;
		$db = $this->GetModel();
		$rec_id = $this->rec_id = urldecode($rec_id);
		$tablename = $this->tablename;
		$fields = array("supplier.id", 
			"supplier.name", 
			"supplier.address", 
			"supplier.type", 
			"supplier.email", 
			"supplier.cc_email", 
			"supplier.whatsapp", 
			"supplier.logo", 
			"supplier.restaurant_id", 
			"user.name AS user_name", 
			"supplier.phone", 
			"supplier.supplier_id");
		if($value){
			$db->where($rec_id, urldecode($value)); //select record based on field name
		}
		else{
			$db->where("supplier.id", $rec_id);; //select record based on primary key
		}
		$db->join("user", "supplier.restaurant_id = user.id", "INNER");  
		$record = $db->getOne($tablename, $fields );
		if($record){
			$page_title = $this->view->page_title = "View  Supplier";
		$this->view->report_filename = date('Y-m-d') . '-' . $page_title;
		$this->view->report_title = $page_title;
		$this->view->report_layout = "report_layout.php";
		$this->view->report_paper_size = "A4";
		$this->view->report_orientation = "portrait";
		}
		else{
			if($db->getLastError()){
				$this->set_page_error();
			}
			else{
				$this->set_page_error("No record found");
			}
		}
		return $this->render_view("supplier/view.php", $record);
	}
	/**
     * Insert new record to the database table
	 * @param $formdata array() from $_POST
     * @return BaseView
     */
	function add($formdata = null){
		if($formdata){
			$db = $this->GetModel();
			$tablename = $this->tablename;
			$request = $this->request;
			//fillable fields
			$fields = $this->fields = array("supplier_id","address","phone","type","email","cc_email","whatsapp","logo","restaurant_id");
			$postdata = $this->format_request_data($formdata);
			$this->rules_array = array(
				'type' => 'required',
				'email' => 'required|valid_email',
				'cc_email' => 'valid_email',
				'logo' => 'required',
				'restaurant_id' => 'required',
			);
			$this->sanitize_array = array(
				'supplier_id' => 'sanitize_string',
				'address' => 'sanitize_string',
				'phone' => 'sanitize_string',
				'type' => 'sanitize_string',
				'email' => 'sanitize_string',
				'cc_email' => 'sanitize_string',
				'whatsapp' => 'sanitize_string',
				'logo' => 'sanitize_string',
				'restaurant_id' => 'sanitize_string',
			);
			$this->filter_vals = true; //set whether to remove empty fields
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			if($this->validated()){
				$rec_id = $this->rec_id = $db->insert($tablename, $modeldata);
				if($rec_id){
		# Statement to execute after adding record
		$db->where("id", $rec_id);
$supplier_id = $db->getValue("supplier", "supplier_id");
$db->where("id", $supplier_id);
$supplier_name = $db->getValue("user", "name");
$table_data = array(
    "name" => $supplier_name
);
$db->where("id", $rec_id);
$bool = $db->update("supplier", $table_data);
		# End of after add statement
					$this->set_flash_msg("Record added successfully", "success");
					return	$this->redirect("supplier");
				}
				else{
					$this->set_page_error();
				}
			}
		}
		$page_title = $this->view->page_title = "Add New Supplier";
		$this->render_view("supplier/add.php");
	}
	/**
     * Update table record with formdata
	 * @param $rec_id (select record by table primary key)
	 * @param $formdata array() from $_POST
     * @return array
     */
	function edit($rec_id = null, $formdata = null){
		$request = $this->request;
		$db = $this->GetModel();
		$this->rec_id = $rec_id;
		$tablename = $this->tablename;
		 //editable fields
		$fields = $this->fields = array("id","supplier_id","address","phone","type","email","cc_email","whatsapp","logo","restaurant_id");
		if($formdata){
			$postdata = $this->format_request_data($formdata);
			$this->rules_array = array(
				'type' => 'required',
				'email' => 'required|valid_email',
				'cc_email' => 'valid_email',
				'logo' => 'required',
				'restaurant_id' => 'required',
			);
			$this->sanitize_array = array(
				'supplier_id' => 'sanitize_string',
				'address' => 'sanitize_string',
				'phone' => 'sanitize_string',
				'type' => 'sanitize_string',
				'email' => 'sanitize_string',
				'cc_email' => 'sanitize_string',
				'whatsapp' => 'sanitize_string',
				'logo' => 'sanitize_string',
				'restaurant_id' => 'sanitize_string',
			);
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			if($this->validated()){
				$db->where("supplier.id", $rec_id);;
				$bool = $db->update($tablename, $modeldata);
				$numRows = $db->getRowCount(); //number of affected rows. 0 = no record field updated
				if($bool && $numRows){
		# Statement to execute after adding record
			$db->where("id", $rec_id);
$supplier_id = $db->getValue("supplier", "supplier_id");
$db->where("id", $supplier_id);
$supplier_name = $db->getValue("user", "name");
$table_data = array(
    "name" => $supplier_name
);
$db->where("id", $rec_id);
$bool = $db->update("supplier", $table_data);
		# End of after update statement
					$this->set_flash_msg("Record updated successfully", "success");
					return $this->redirect("supplier");
				}
				else{
					if($db->getLastError()){
						$this->set_page_error();
					}
					elseif(!$numRows){
						//not an error, but no record was updated
						$page_error = "No record updated";
						$this->set_page_error($page_error);
						$this->set_flash_msg($page_error, "warning");
						return	$this->redirect("supplier");
					}
				}
			}
		}
		$db->where("supplier.id", $rec_id);;
		$data = $db->getOne($tablename, $fields);
		$page_title = $this->view->page_title = "Edit  Supplier";
		if(!$data){
			$this->set_page_error();
		}
		return $this->render_view("supplier/edit.php", $data);
	}
	/**
     * Update single field
	 * @param $rec_id (select record by table primary key)
	 * @param $formdata array() from $_POST
     * @return array
     */
	function editfield($rec_id = null, $formdata = null){
		$db = $this->GetModel();
		$this->rec_id = $rec_id;
		$tablename = $this->tablename;
		//editable fields
		$fields = $this->fields = array("id","supplier_id","address","phone","type","email","cc_email","whatsapp","logo","restaurant_id");
		$page_error = null;
		if($formdata){
			$postdata = array();
			$fieldname = $formdata['name'];
			$fieldvalue = $formdata['value'];
			$postdata[$fieldname] = $fieldvalue;
			$postdata = $this->format_request_data($postdata);
			$this->rules_array = array(
				'type' => 'required',
				'email' => 'required|valid_email',
				'cc_email' => 'valid_email',
				'logo' => 'required',
				'restaurant_id' => 'required',
			);
			$this->sanitize_array = array(
				'supplier_id' => 'sanitize_string',
				'address' => 'sanitize_string',
				'phone' => 'sanitize_string',
				'type' => 'sanitize_string',
				'email' => 'sanitize_string',
				'cc_email' => 'sanitize_string',
				'whatsapp' => 'sanitize_string',
				'logo' => 'sanitize_string',
				'restaurant_id' => 'sanitize_string',
			);
			$this->filter_rules = true; //filter validation rules by excluding fields not in the formdata
			$modeldata = $this->modeldata = $this->validate_form($postdata);
			if($this->validated()){
				$db->where("supplier.id", $rec_id);;
				$bool = $db->update($tablename, $modeldata);
				$numRows = $db->getRowCount();
				if($bool && $numRows){
					return render_json(
						array(
							'num_rows' =>$numRows,
							'rec_id' =>$rec_id,
						)
					);
				}
				else{
					if($db->getLastError()){
						$page_error = $db->getLastError();
					}
					elseif(!$numRows){
						$page_error = "No record updated";
					}
					render_error($page_error);
				}
			}
			else{
				render_error($this->view->page_error);
			}
		}
		return null;
	}
	/**
     * Delete record from the database
	 * Support multi delete by separating record id by comma.
     * @return BaseView
     */
	function delete($rec_id = null){
		Csrf::cross_check();
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$this->rec_id = $rec_id;
		//form multiple delete, split record id separated by comma into array
		$arr_rec_id = array_map('trim', explode(",", $rec_id));
	#Statement to execute before delete record
	$db->where("id", $rec_id);
$supplier_id = $db->getValue("supplier", "supplier_id");
$params = array($supplier_id);
$bool   = $db->rawQuery("DELETE FROM product WHERE supplier_id = ?", $params);
	# End of before delete statement
		$db->where("supplier.id", $arr_rec_id, "in");
		$bool = $db->delete($tablename);
		if($bool){
			$this->set_flash_msg("Record deleted successfully", "success");
		}
		elseif($db->getLastError()){
			$page_error = $db->getLastError();
			$this->set_flash_msg($page_error, "danger");
		}
		return	$this->redirect("supplier");
	}
	/**
     * List page records
     * @param $fieldname (filter record by a field) 
     * @param $fieldvalue (filter field value)
     * @return BaseView
     */
	function supplier_list($fieldname = null , $fieldvalue = null){
		$request = $this->request;
		$db = $this->GetModel();
		$tablename = $this->tablename;
		$fields = array("supplier.id", 
			"supplier.logo", 
			"supplier.name", 
			"supplier.address", 
			"supplier.phone", 
			"supplier.type", 
			"supplier.email", 
			"supplier.cc_email", 
			"supplier.whatsapp", 
			"supplier.restaurant_id", 
			"user.name AS user_name", 
			"supplier.supplier_id");
		$pagination = $this->get_pagination(MAX_RECORD_COUNT); // get current pagination e.g array(page_number, page_limit)
		//search table record
		if(!empty($request->search)){
			$text = trim($request->search); 
			$search_condition = "(
				supplier.id LIKE ? OR 
				supplier.logo LIKE ? OR 
				supplier.name LIKE ? OR 
				supplier.address LIKE ? OR 
				supplier.phone LIKE ? OR 
				supplier.type LIKE ? OR 
				supplier.email LIKE ? OR 
				supplier.cc_email LIKE ? OR 
				supplier.whatsapp LIKE ? OR 
				supplier.restaurant_id LIKE ? OR 
				supplier.supplier_id LIKE ?
			)";
			$search_params = array(
				"%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%","%$text%"
			);
			//setting search conditions
			$db->where($search_condition, $search_params);
			 //template to use when ajax search
			$this->view->search_template = "supplier/search.php";
		}
		$db->join("user", "supplier.restaurant_id = user.id", "INNER");
		if(!empty($request->orderby)){
			$orderby = $request->orderby;
			$ordertype = (!empty($request->ordertype) ? $request->ordertype : ORDER_TYPE);
			$db->orderBy($orderby, $ordertype);
		}
		else{
			$db->orderBy("supplier.id", ORDER_TYPE);
		}
		$db->where("restaurant_id='". USER_ID . "'");
		if($fieldname){
			$db->where($fieldname , $fieldvalue); //filter by a single field name
		}
		$tc = $db->withTotalCount();
		$records = $db->get($tablename, $pagination, $fields);
		$records_count = count($records);
		$total_records = intval($tc->totalCount);
		$page_limit = $pagination[1];
		$total_pages = ceil($total_records / $page_limit);
		$data = new stdClass;
		$data->records = $records;
		$data->record_count = $records_count;
		$data->total_records = $total_records;
		$data->total_page = $total_pages;
		if($db->getLastError()){
			$this->set_page_error();
		}
		$page_title = $this->view->page_title = "Supplier";
		$this->render_view("supplier/supplier_list.php", $data); //render the full page
	}
	/**
     * View record detail 
	 * @param $rec_id (select record by table primary key) 
     * @param $value value (select record by value of field name(rec_id))
     * @return BaseView
     */
	function supplier_view($rec_id = null, $value = null){
		$request = $this->request;
		$db = $this->GetModel();
		$rec_id = $this->rec_id = urldecode($rec_id);
		$tablename = $this->tablename;
		$fields = array("supplier.id", 
			"supplier.name", 
			"supplier.address", 
			"supplier.type", 
			"supplier.email", 
			"supplier.cc_email", 
			"supplier.whatsapp", 
			"supplier.logo", 
			"supplier.restaurant_id", 
			"user.name AS user_name", 
			"supplier.phone", 
			"supplier.supplier_id");
		if($value){
			$db->where($rec_id, urldecode($value)); //select record based on field name
		}
		else{
			$db->where("supplier.id", $rec_id);; //select record based on primary key
		}
		$db->join("user", "supplier.restaurant_id = user.id", "INNER");  
		$record = $db->getOne($tablename, $fields );
		if($record){
			$page_title = $this->view->page_title = "View  Supplier";
		}
		else{
			if($db->getLastError()){
				$this->set_page_error();
			}
			else{
				$this->set_page_error("No record found");
			}
		}
		return $this->render_view("supplier/supplier_view.php", $record);
	}
}
